C$Procedure  RAYOCC   ( ray occlusion by a plate )
 
      LOGICAL FUNCTION RAYOCC ( START, RAYDIR, PLDEX, DIST )
 
C$ Abstract
C
C     Determine if a ray is intersected by a given plate.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE OCCLUSION
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               PLDEX
 
      DOUBLE PRECISION      DIST
      DOUBLE PRECISION      START   ( 3 )
      DOUBLE PRECISION      RAYDIR  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     START      I   Ray starting point coordinates.
C     RAYDIR     I   Ray direction vector from START.
C     PLDEX      I   Plate ID.
C     RAYOCC     O   .TRUE. if ray hits plate PLDEX.
C     DIST       O   Distance to intersection along the ray.
C
C$ Detailed_Input
C
C     START      Ray starting point coordinates.
C
C     RAYDIR     Ray direction vector from START.
C
C     PLDEX      Plate ID.
C
C$ Detailed_Output
C
C     RAYOCC     .TRUE. if ray hits plate PLDEX.
C
C     DIST       Distance to intersection along the ray.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1)
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     test for ray occlusion by a plate
C
C-&
 
 
C
C     Local variables.
C
 
      LOGICAL               FOUND
      LOGICAL               RETURN
 
      DOUBLE PRECISION      E1      ( 3 )
      DOUBLE PRECISION      E2      ( 3 )
      DOUBLE PRECISION      E3      ( 3 )
      DOUBLE PRECISION      POINTS  ( 3, 3 )
 
 
 
      RAYOCC = .FALSE.
 
C
C     Standard SPICELIB error handling.
C
 
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'RAYOCC' )
 
 
      CALL NTHPLV ( PLDEX, POINTS )
 
      CALL VSUB   ( POINTS(1,1), START, E1 )
      CALL VSUB   ( POINTS(1,2), START, E2 )
      CALL VSUB   ( POINTS(1,3), START, E3 )
 
      CALL INSANG ( RAYDIR, E1, E2, E3, FOUND, DIST )
 
      IF ( .NOT. FOUND ) THEN
         CALL CHKOUT ( 'RAYOCC' )
         RETURN
      END IF
      RAYOCC = .TRUE.
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'RAYOCC' )
 
 
      RETURN
      END
