C$Procedure      UNTNGL ( untangle an AB linked-cell list  )
 
      SUBROUTINE UNTNGL ( NPTR, INPTR, MAXB, BVAL, CELLS, OUTPTR, NOUT,
     .                    OUTLST )
 
 
C$ Abstract
C
C     Untangle an unsorted AB linked-cell list into
C     an A-index and associated B-list.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     AB linked list
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NPTR
      INTEGER               MAXB
      INTEGER               NOUT
      INTEGER               INPTR     ( * )
      INTEGER               OUTPTR    ( * )
      INTEGER               OUTLST    ( * )
      INTEGER               CELLS     ( 3, * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NPTR       I   Length of A-list.
C     INPTR      I   Pointers into AB cell linked-list.
C     MAXB       I   Maximum allowed dimension of B list.
C     CELLS      I   AB cell linked list.
C     OUTPTR     O   A-index array.
C     NOUT       O   Length of B-list.
C     OUTLST     O   B-list.
C
C$ Detailed_Input
C
C     NPTR
C
C     INPTR
C
C     MAXB
C
C$ Detailed_Output
C
C     OUTPTR
C
C
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     AB linked list
C
C-&
 
 
C
C     Local Variables
C
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               NB
      INTEGER               AVAL
      INTEGER               PTRDEX
      INTEGER               BVAL      ( MAXB )
 
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'UNTNGL' )
 
C
C     Initialize pointer index.
C
 
      PTRDEX = 0
 
C
C     Loop over all A-values.
C
 
      DO AVAL = 1, NPTR
 
C
C     Traverse the chained list for a
C     particular A-value and collect associated B-values.
C
 
         CALL TRVLNK ( AVAL, INPTR, CELLS, NB, BVAL )
 
C
C     Increment pointer and list.
C
         IF ( NB .NE. 0 ) THEN
 
            PTRDEX = PTRDEX + 1
            OUTPTR(AVAL) = PTRDEX
            OUTLST(PTRDEX) = NB
 
            DO I = 1, NB
               PTRDEX = PTRDEX + 1
               OUTLST(PTRDEX) = BVAL(I)
            END DO
 
         ELSE
C
C     If no associated B-values exist, set null pointer.
C
            OUTPTR(AVAL) = -1
 
         END IF
 
      END DO
 
      NOUT = PTRDEX
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'UNTNGL' )
 
 
      RETURN
      END
